#ifndef lint
static char SccsStructId[] = "%W%  %G%";
#endif

/* Module:	Struct.h
 * Purpose:	Declare all of the major structure types
 * Modified:	{0} Michael VanHilst	initial version		  5 June 1989
 *		{1} Doug Mink           added wcs                 6 July 1995
 *		{n} <who> -- <does what> -- <when>
 */

#include "color.h"
#include "control.h"
#include "coord.h"
#include "cursor.h"
#include "image.h"
#include "window.h"
#include "buffer.h"
#include "wcs.h"
